@@ -62,7 +62,8 @@ void KnutResource::load()
     }
 
     if (!QFile::exists(fileName)) {
-        fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/akonadi_knut_resource/knut-template.xml"));
+        fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                          QStringLiteral("kf" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/akonadi_knut_resource/knut-template.xml"));
     }
 
     if (!mDocument.loadFile(fileName)) {
@@ -121,7 +122,7 @@ void KnutResource::retrieveCollections()
     const Collection::List collections = mDocument.collections();
     collectionsRetrieved(collections);
     const Tag::List tags = mDocument.tags();
-    Q_FOREACH (const Tag &tag, tags) {
+    for (const Tag &tag : tags) {
         auto createjob = new TagCreateJob(tag);
         createjob->setMergeIfExisting(true);
     }
@@ -336,7 +337,8 @@ QSet<qint64> KnutResource::parseQuery(const QString &queryString)
 {
     QSet<qint64> resultSet;
     Akonadi::SearchQuery query = Akonadi::SearchQuery::fromJSON(queryString.toLatin1());
-    foreach (const Akonadi::SearchTerm &term, query.term().subTerms()) {
+    const QList<SearchTerm> subTerms = query.term().subTerms();
+    for (const Akonadi::SearchTerm &term : subTerms) {
         if (term.key() == QLatin1String("resource")) {
             resultSet << term.value().toInt();
         }
