@@ -4,15 +4,17 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_COLLECTIONFILTERPROXYMODEL_H
-#define AKONADI_COLLECTIONFILTERPROXYMODEL_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include <QSortFilterProxyModel>
 
+#include <memory>
+
 namespace Akonadi
 {
 class CollectionModel;
+class CollectionFilterProxyModelPrivate;
 
 /**
  * @short A proxy model that filters collections by mime type.
@@ -100,11 +102,9 @@ protected:
 
 private:
     /// @cond PRIVATE
-    class Private;
-    Private *const d;
+    friend class CollectionFilterProxyModelPrivate;
+    std::unique_ptr<CollectionFilterProxyModelPrivate> const d;
     /// @endcond
 };
 
 }
-
-#endif
