@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKSTANDARDDIRS_P_H
-#define AKSTANDARDDIRS_P_H
+#pragma once
 
 #include "akonadiprivate_export.h"
 
@@ -25,7 +24,11 @@ namespace StandardDirs
  * FileAccessMode is a typedef for QFlags<FileAccessFlag>. It stores
  * a OR combination of FileAccessFlag values
  */
-enum FileAccessMode { ReadOnly = 0x1, WriteOnly = 0x2, ReadWrite = ReadOnly | WriteOnly };
+enum FileAccessMode {
+    ReadOnly = 0x1,
+    WriteOnly = 0x2,
+    ReadWrite = ReadOnly | WriteOnly,
+};
 
 /**
  * Returns path to the config file @p configFile.
@@ -94,5 +97,3 @@ AKONADIPRIVATE_EXPORT QString findExecutable(const QString &relPath);
 
 }
 }
-
-#endif
