@@ -52,18 +52,9 @@ static QString sqliteDataFile()
     return akonadiPath;
 }
 
-DbConfigSqlite::DbConfigSqlite(Version driverVersion)
-    : mDriverVersion(driverVersion)
-{
-}
-
 QString DbConfigSqlite::driverName() const
 {
-    if (mDriverVersion == Default) {
-        return QStringLiteral("QSQLITE");
-    } else {
-        return QStringLiteral("QSQLITE3");
-    }
+    return QStringLiteral("QSQLITE");
 }
 
 QString DbConfigSqlite::databaseName() const
@@ -127,9 +118,6 @@ void DbConfigSqlite::apply(QSqlDatabase &database)
         database.setPassword(mPassword);
     }
 
-    if (driverName() == QLatin1String("QSQLITE3") && !mConnectionOptions.contains(QLatin1String("SQLITE_ENABLE_SHARED_CACHE"))) {
-        mConnectionOptions += QLatin1String(";QSQLITE_ENABLE_SHARED_CACHE");
-    }
     database.setConnectOptions(mConnectionOptions);
 
     // can we check that during init() already?
